@@ -1,15 +1,6 @@
 from horus.tests import UnitTestBase
 
 class TestInterfaces(UnitTestBase):
-    def test_susession(self):
-        """ Shouldn't be able to instantiate the interface """
-        from horus.interfaces import IHorusSession
-
-        def make_session():
-            IHorusSession('1')
-
-        self.assertRaises(TypeError, make_session)
-
     def test_suloginschema(self):
         """ Shouldn't be able to instantiate the interface """
         from horus.interfaces import IHorusLoginSchema
